### Name: kalord
### Title: Repeated Measurements Models for Ordinal Variables with Frailty
###   or Serial Dependence
### Aliases: kalord print.kalordinal deviance.kalordinal fitted.kalordinal
### Keywords: models

### ** Examples

library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant covariate.
kalord(w,distribution="binary",ccov=~age,preg=c(3.9507,-0.0308),pinit=NULL)

# Time-varying covariate.
kalord(w,distribution="binary",tvcov=~times,preg=1.832,ptvc=0.0573,pinit=NULL)

# Time-constant and time-varying covariate.
kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
       ptvc=c(3.888,-0.0289,-0.642,-0.366,-0.314,-0.154,-0.114,0.057),pinit=NULL)

# Time-constant and time-varying covariate with a frailty dependence.
kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
       ptvc=c(4.43391,-0.03128,-0.62439,-0.37596,-0.33064,-0.17095,-0.12216,-0.09096),
       pinit=0.1196,dep="frailty")

rm(w)

#
# Ordinal data
#
data(tmi2)

y <- restovec(tmi2[,1:4],type="ordinal")

cov <- tcctomat(tmi2[,5],name="distance")

w <- rmna(y,ccov=cov)

rm(tmi2,y,cov)

# Continuation-ratio model with time-constant covariate with a serial dependence.
kalord(w,distribution="continuation-ratio",ccov=~distance,preg=c(-1.907,7.7,-0.162),
       pinit=2.55,pdep=0.328,dep="serial")

# Proportional-odds model with time-constant covariate with a Markov dependence.
kalord(w,distribution="proportional-odds",ccov=~distance,preg=c(-1.89,11.652,-0.199),
        pinit=3.111,pdep=0.217,dep="Markov")

rm(w)



